/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediaplayer.sip"
#include <qmediaplayer.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qplaybackoptions.sip"
#include <qplaybackoptions.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudiobufferoutput.sip"
#include <qaudiobufferoutput.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediametadata.sip"
#include <qmediametadata.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediatimerange.sip"
#include <qmediatimerange.h>
#line 54 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qvideosink.sip"
#include <qvideosink.h>
#line 57 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qaudiooutput.sip"
#include <qaudiooutput.h>
#line 60 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 63 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 112 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQMediaPlayer.cpp"


class sipQMediaPlayer : public ::QMediaPlayer
{
public:
    sipQMediaPlayer(::QObject*);
    virtual ~sipQMediaPlayer();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQMediaPlayer(const sipQMediaPlayer &);
    sipQMediaPlayer &operator = (const sipQMediaPlayer &);

    char sipPyMethods[7];
};

sipQMediaPlayer::sipQMediaPlayer(::QObject*a0): ::QMediaPlayer(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQMediaPlayer::~sipQMediaPlayer()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQMediaPlayer::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QMediaPlayer);

    return ::QMediaPlayer::metaObject();
}

int sipQMediaPlayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QMediaPlayer::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QMediaPlayer, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQMediaPlayer::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QMediaPlayer, _clname, &sipCpp) ? sipCpp : ::QMediaPlayer::qt_metacast(_clname));
}

bool sipQMediaPlayer::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QMediaPlayer::event(a0);

    extern bool sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQMediaPlayer::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QMediaPlayer::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_4(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQMediaPlayer::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QMediaPlayer::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_3(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayer::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QMediaPlayer::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayer::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QMediaPlayer::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_1(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayer::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QMediaPlayer::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayer::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QMediaPlayer::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QMediaPlayer_audioTracks, "audioTracks(self) -> list[QMediaMetaData]");

extern "C" {static PyObject *meth_QMediaPlayer_audioTracks(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_audioTracks(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            QList< ::QMediaMetaData>*sipRes;

            sipRes = new QList< ::QMediaMetaData>(sipCpp->audioTracks());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QMediaMetaData, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_audioTracks, doc_QMediaPlayer_audioTracks);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_videoTracks, "videoTracks(self) -> list[QMediaMetaData]");

extern "C" {static PyObject *meth_QMediaPlayer_videoTracks(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_videoTracks(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            QList< ::QMediaMetaData>*sipRes;

            sipRes = new QList< ::QMediaMetaData>(sipCpp->videoTracks());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QMediaMetaData, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_videoTracks, doc_QMediaPlayer_videoTracks);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_subtitleTracks, "subtitleTracks(self) -> list[QMediaMetaData]");

extern "C" {static PyObject *meth_QMediaPlayer_subtitleTracks(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_subtitleTracks(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            QList< ::QMediaMetaData>*sipRes;

            sipRes = new QList< ::QMediaMetaData>(sipCpp->subtitleTracks());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QMediaMetaData, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_subtitleTracks, doc_QMediaPlayer_subtitleTracks);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_activeAudioTrack, "activeAudioTrack(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayer_activeAudioTrack(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_activeAudioTrack(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->activeAudioTrack();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_activeAudioTrack, doc_QMediaPlayer_activeAudioTrack);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_activeVideoTrack, "activeVideoTrack(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayer_activeVideoTrack(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_activeVideoTrack(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->activeVideoTrack();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_activeVideoTrack, doc_QMediaPlayer_activeVideoTrack);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_activeSubtitleTrack, "activeSubtitleTrack(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayer_activeSubtitleTrack(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_activeSubtitleTrack(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->activeSubtitleTrack();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_activeSubtitleTrack, doc_QMediaPlayer_activeSubtitleTrack);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setActiveAudioTrack, "setActiveAudioTrack(self, index: int)");

extern "C" {static PyObject *meth_QMediaPlayer_setActiveAudioTrack(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setActiveAudioTrack(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaPlayer, &sipCpp, &a0))
        {
            sipCpp->setActiveAudioTrack(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setActiveAudioTrack, doc_QMediaPlayer_setActiveAudioTrack);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setActiveVideoTrack, "setActiveVideoTrack(self, index: int)");

extern "C" {static PyObject *meth_QMediaPlayer_setActiveVideoTrack(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setActiveVideoTrack(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaPlayer, &sipCpp, &a0))
        {
            sipCpp->setActiveVideoTrack(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setActiveVideoTrack, doc_QMediaPlayer_setActiveVideoTrack);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setActiveSubtitleTrack, "setActiveSubtitleTrack(self, index: int)");

extern "C" {static PyObject *meth_QMediaPlayer_setActiveSubtitleTrack(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setActiveSubtitleTrack(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaPlayer, &sipCpp, &a0))
        {
            sipCpp->setActiveSubtitleTrack(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setActiveSubtitleTrack, doc_QMediaPlayer_setActiveSubtitleTrack);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setAudioOutput, "setAudioOutput(self, output: QAudioOutput|None)");

extern "C" {static PyObject *meth_QMediaPlayer_setAudioOutput(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setAudioOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioOutput* a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QAudioOutput, &a0))
        {
            sipCpp->setAudioOutput(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setAudioOutput, doc_QMediaPlayer_setAudioOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_audioOutput, "audioOutput(self) -> QAudioOutput|None");

extern "C" {static PyObject *meth_QMediaPlayer_audioOutput(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_audioOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QAudioOutput*sipRes;

            sipRes = sipCpp->audioOutput();

            return sipConvertFromType(sipRes, sipType_QAudioOutput, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_audioOutput, doc_QMediaPlayer_audioOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setVideoOutput, "setVideoOutput(self, a0: QObject|None)");

extern "C" {static PyObject *meth_QMediaPlayer_setVideoOutput(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setVideoOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QObject, &a0))
        {
            sipCpp->setVideoOutput(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setVideoOutput, doc_QMediaPlayer_setVideoOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_videoOutput, "videoOutput(self) -> QObject|None");

extern "C" {static PyObject *meth_QMediaPlayer_videoOutput(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_videoOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QObject*sipRes;

            sipRes = sipCpp->videoOutput();

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_videoOutput, doc_QMediaPlayer_videoOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setVideoSink, "setVideoSink(self, sink: QVideoSink|None)");

extern "C" {static PyObject *meth_QMediaPlayer_setVideoSink(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setVideoSink(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVideoSink* a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QVideoSink, &a0))
        {
            sipCpp->setVideoSink(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setVideoSink, doc_QMediaPlayer_setVideoSink);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_videoSink, "videoSink(self) -> QVideoSink|None");

extern "C" {static PyObject *meth_QMediaPlayer_videoSink(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_videoSink(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QVideoSink*sipRes;

            sipRes = sipCpp->videoSink();

            return sipConvertFromType(sipRes, sipType_QVideoSink, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_videoSink, doc_QMediaPlayer_videoSink);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_source, "source(self) -> QUrl");

extern "C" {static PyObject *meth_QMediaPlayer_source(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_source(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->source());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_source, doc_QMediaPlayer_source);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_sourceDevice, "sourceDevice(self) -> QIODevice|None");

extern "C" {static PyObject *meth_QMediaPlayer_sourceDevice(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_sourceDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            const ::QIODevice*sipRes;

            sipRes = sipCpp->sourceDevice();

            return sipConvertFromType(const_cast< ::QIODevice *>(sipRes), sipType_QIODevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_sourceDevice, doc_QMediaPlayer_sourceDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_playbackState, "playbackState(self) -> QMediaPlayer.PlaybackState");

extern "C" {static PyObject *meth_QMediaPlayer_playbackState(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_playbackState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMediaPlayer::PlaybackState sipRes;

            sipRes = sipCpp->playbackState();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaPlayer_PlaybackState);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_playbackState, doc_QMediaPlayer_playbackState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_mediaStatus, "mediaStatus(self) -> QMediaPlayer.MediaStatus");

extern "C" {static PyObject *meth_QMediaPlayer_mediaStatus(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_mediaStatus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMediaPlayer::MediaStatus sipRes;

            sipRes = sipCpp->mediaStatus();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaPlayer_MediaStatus);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_mediaStatus, doc_QMediaPlayer_mediaStatus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_duration, "duration(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayer_duration(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_duration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->duration();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_duration, doc_QMediaPlayer_duration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_position, "position(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayer_position(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->position();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_position, doc_QMediaPlayer_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_hasAudio, "hasAudio(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayer_hasAudio(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_hasAudio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasAudio();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_hasAudio, doc_QMediaPlayer_hasAudio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_hasVideo, "hasVideo(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayer_hasVideo(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_hasVideo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasVideo();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_hasVideo, doc_QMediaPlayer_hasVideo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_bufferProgress, "bufferProgress(self) -> float");

extern "C" {static PyObject *meth_QMediaPlayer_bufferProgress(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_bufferProgress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->bufferProgress();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_bufferProgress, doc_QMediaPlayer_bufferProgress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_bufferedTimeRange, "bufferedTimeRange(self) -> QMediaTimeRange");

extern "C" {static PyObject *meth_QMediaPlayer_bufferedTimeRange(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_bufferedTimeRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMediaTimeRange*sipRes;

            sipRes = new ::QMediaTimeRange(sipCpp->bufferedTimeRange());

            return sipConvertFromNewType(sipRes, sipType_QMediaTimeRange, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_bufferedTimeRange, doc_QMediaPlayer_bufferedTimeRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_isSeekable, "isSeekable(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayer_isSeekable(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_isSeekable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSeekable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_isSeekable, doc_QMediaPlayer_isSeekable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_playbackRate, "playbackRate(self) -> float");

extern "C" {static PyObject *meth_QMediaPlayer_playbackRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_playbackRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->playbackRate();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_playbackRate, doc_QMediaPlayer_playbackRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_error, "error(self) -> QMediaPlayer.Error");

extern "C" {static PyObject *meth_QMediaPlayer_error(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMediaPlayer::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaPlayer_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_error, doc_QMediaPlayer_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QMediaPlayer_errorString(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_errorString, doc_QMediaPlayer_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_isAvailable, "isAvailable(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayer_isAvailable(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_isAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_isAvailable, doc_QMediaPlayer_isAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_metaData, "metaData(self) -> QMediaMetaData");

extern "C" {static PyObject *meth_QMediaPlayer_metaData(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_metaData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMediaMetaData*sipRes;

            sipRes = new ::QMediaMetaData(sipCpp->metaData());

            return sipConvertFromNewType(sipRes, sipType_QMediaMetaData, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_metaData, doc_QMediaPlayer_metaData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_play, "play(self)");

extern "C" {static PyObject *meth_QMediaPlayer_play(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_play(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            sipCpp->play();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_play, doc_QMediaPlayer_play);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_pause, "pause(self)");

extern "C" {static PyObject *meth_QMediaPlayer_pause(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_pause(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            sipCpp->pause();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_pause, doc_QMediaPlayer_pause);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_stop, "stop(self)");

extern "C" {static PyObject *meth_QMediaPlayer_stop(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_stop, doc_QMediaPlayer_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setPosition, "setPosition(self, position: int)");

extern "C" {static PyObject *meth_QMediaPlayer_setPosition(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QMediaPlayer, &sipCpp, &a0))
        {
            sipCpp->setPosition(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setPosition, doc_QMediaPlayer_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setPlaybackRate, "setPlaybackRate(self, rate: float)");

extern "C" {static PyObject *meth_QMediaPlayer_setPlaybackRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setPlaybackRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QMediaPlayer, &sipCpp, &a0))
        {
            sipCpp->setPlaybackRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setPlaybackRate, doc_QMediaPlayer_setPlaybackRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setSource, "setSource(self, source: QUrl)");

extern "C" {static PyObject *meth_QMediaPlayer_setSource(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QUrl, &a0))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->setSource(*a0);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setSource, doc_QMediaPlayer_setSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setSourceDevice, "setSourceDevice(self, device: QIODevice|None, sourceUrl: QUrl = QUrl())");

extern "C" {static PyObject *meth_QMediaPlayer_setSourceDevice(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setSourceDevice(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        const ::QUrl& a1def = QUrl();
        const ::QUrl* a1 = &a1def;
        ::QMediaPlayer *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_sourceUrl,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|J9", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QIODevice, &a0, sipType_QUrl, &a1))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->setSourceDevice(a0, *a1);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setSourceDevice, doc_QMediaPlayer_setSourceDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_loops, "loops(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayer_loops(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_loops(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->loops();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_loops, doc_QMediaPlayer_loops);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setLoops, "setLoops(self, loops: int)");

extern "C" {static PyObject *meth_QMediaPlayer_setLoops(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setLoops(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaPlayer, &sipCpp, &a0))
        {
            sipCpp->setLoops(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setLoops, doc_QMediaPlayer_setLoops);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_isPlaying, "isPlaying(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayer_isPlaying(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_isPlaying(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isPlaying();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_isPlaying, doc_QMediaPlayer_isPlaying);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setAudioBufferOutput, "setAudioBufferOutput(self, output: QAudioBufferOutput|None)");

extern "C" {static PyObject *meth_QMediaPlayer_setAudioBufferOutput(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setAudioBufferOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioBufferOutput* a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QAudioBufferOutput, &a0))
        {
            sipCpp->setAudioBufferOutput(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setAudioBufferOutput, doc_QMediaPlayer_setAudioBufferOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_audioBufferOutput, "audioBufferOutput(self) -> QAudioBufferOutput|None");

extern "C" {static PyObject *meth_QMediaPlayer_audioBufferOutput(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_audioBufferOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QAudioBufferOutput*sipRes;

            sipRes = sipCpp->audioBufferOutput();

            return sipConvertFromType(sipRes, sipType_QAudioBufferOutput, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_audioBufferOutput, doc_QMediaPlayer_audioBufferOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_pitchCompensationAvailability, "pitchCompensationAvailability(self) -> QMediaPlayer.PitchCompensationAvailability");

extern "C" {static PyObject *meth_QMediaPlayer_pitchCompensationAvailability(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_pitchCompensationAvailability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QMediaPlayer::PitchCompensationAvailability sipRes;

            sipRes = sipCpp->pitchCompensationAvailability();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaPlayer_PitchCompensationAvailability);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_pitchCompensationAvailability, doc_QMediaPlayer_pitchCompensationAvailability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_pitchCompensation, "pitchCompensation(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayer_pitchCompensation(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_pitchCompensation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->pitchCompensation();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_pitchCompensation, doc_QMediaPlayer_pitchCompensation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_playbackOptions, "playbackOptions(self) -> QPlaybackOptions");

extern "C" {static PyObject *meth_QMediaPlayer_playbackOptions(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_playbackOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            ::QPlaybackOptions*sipRes;

            sipRes = new ::QPlaybackOptions(sipCpp->playbackOptions());

            return sipConvertFromNewType(sipRes, sipType_QPlaybackOptions, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_playbackOptions, doc_QMediaPlayer_playbackOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setPitchCompensation, "setPitchCompensation(self, a0: bool)");

extern "C" {static PyObject *meth_QMediaPlayer_setPitchCompensation(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setPitchCompensation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        const ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QMediaPlayer, &sipCpp, &a0))
        {
            sipCpp->setPitchCompensation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setPitchCompensation, doc_QMediaPlayer_setPitchCompensation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_setPlaybackOptions, "setPlaybackOptions(self, options: QPlaybackOptions)");

extern "C" {static PyObject *meth_QMediaPlayer_setPlaybackOptions(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_setPlaybackOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaybackOptions* a0;
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QMediaPlayer, &sipCpp, sipType_QPlaybackOptions, &a0))
        {
            sipCpp->setPlaybackOptions(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_setPlaybackOptions, doc_QMediaPlayer_setPlaybackOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayer_resetPlaybackOptions, "resetPlaybackOptions(self)");

extern "C" {static PyObject *meth_QMediaPlayer_resetPlaybackOptions(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayer_resetPlaybackOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlayer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayer, &sipCpp))
        {
            sipCpp->resetPlaybackOptions();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayer, sipName_resetPlaybackOptions, doc_QMediaPlayer_resetPlaybackOptions);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QMediaPlayer(void *, const sipTypeDef *);}
static void *cast_QMediaPlayer(void *sipCppV, const sipTypeDef *targetType)
{
    ::QMediaPlayer *sipCpp = reinterpret_cast< ::QMediaPlayer *>(sipCppV);

    if (targetType == sipType_QMediaPlayer)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QMediaPlayer(void *, int);}
static void release_QMediaPlayer(void *sipCppV, int)
{
    ::QMediaPlayer *sipCpp = reinterpret_cast< ::QMediaPlayer *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QMediaPlayer(Py_ssize_t);}
static void *array_QMediaPlayer(Py_ssize_t sipNrElem)
{
    return new ::QMediaPlayer[sipNrElem];
}


extern "C" {static void array_delete_QMediaPlayer(void *);}
static void array_delete_QMediaPlayer(void *sipCpp)
{
    delete[] reinterpret_cast< ::QMediaPlayer *>(sipCpp);
}


extern "C" {static void dealloc_QMediaPlayer(sipSimpleWrapper *);}
static void dealloc_QMediaPlayer(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQMediaPlayer *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMediaPlayer(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QMediaPlayer(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMediaPlayer(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQMediaPlayer *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQMediaPlayer(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QMediaPlayer[] = {{7, 0, 1}};


static PyMethodDef methods_QMediaPlayer[] = {
    {sipName_activeAudioTrack, meth_QMediaPlayer_activeAudioTrack, METH_VARARGS, doc_QMediaPlayer_activeAudioTrack},
    {sipName_activeSubtitleTrack, meth_QMediaPlayer_activeSubtitleTrack, METH_VARARGS, doc_QMediaPlayer_activeSubtitleTrack},
    {sipName_activeVideoTrack, meth_QMediaPlayer_activeVideoTrack, METH_VARARGS, doc_QMediaPlayer_activeVideoTrack},
    {sipName_audioBufferOutput, meth_QMediaPlayer_audioBufferOutput, METH_VARARGS, doc_QMediaPlayer_audioBufferOutput},
    {sipName_audioOutput, meth_QMediaPlayer_audioOutput, METH_VARARGS, doc_QMediaPlayer_audioOutput},
    {sipName_audioTracks, meth_QMediaPlayer_audioTracks, METH_VARARGS, doc_QMediaPlayer_audioTracks},
    {sipName_bufferProgress, meth_QMediaPlayer_bufferProgress, METH_VARARGS, doc_QMediaPlayer_bufferProgress},
    {sipName_bufferedTimeRange, meth_QMediaPlayer_bufferedTimeRange, METH_VARARGS, doc_QMediaPlayer_bufferedTimeRange},
    {sipName_duration, meth_QMediaPlayer_duration, METH_VARARGS, doc_QMediaPlayer_duration},
    {sipName_error, meth_QMediaPlayer_error, METH_VARARGS, doc_QMediaPlayer_error},
    {sipName_errorString, meth_QMediaPlayer_errorString, METH_VARARGS, doc_QMediaPlayer_errorString},
    {sipName_hasAudio, meth_QMediaPlayer_hasAudio, METH_VARARGS, doc_QMediaPlayer_hasAudio},
    {sipName_hasVideo, meth_QMediaPlayer_hasVideo, METH_VARARGS, doc_QMediaPlayer_hasVideo},
    {sipName_isAvailable, meth_QMediaPlayer_isAvailable, METH_VARARGS, doc_QMediaPlayer_isAvailable},
    {sipName_isPlaying, meth_QMediaPlayer_isPlaying, METH_VARARGS, doc_QMediaPlayer_isPlaying},
    {sipName_isSeekable, meth_QMediaPlayer_isSeekable, METH_VARARGS, doc_QMediaPlayer_isSeekable},
    {sipName_loops, meth_QMediaPlayer_loops, METH_VARARGS, doc_QMediaPlayer_loops},
    {sipName_mediaStatus, meth_QMediaPlayer_mediaStatus, METH_VARARGS, doc_QMediaPlayer_mediaStatus},
    {sipName_metaData, meth_QMediaPlayer_metaData, METH_VARARGS, doc_QMediaPlayer_metaData},
    {sipName_pause, meth_QMediaPlayer_pause, METH_VARARGS, doc_QMediaPlayer_pause},
    {sipName_pitchCompensation, meth_QMediaPlayer_pitchCompensation, METH_VARARGS, doc_QMediaPlayer_pitchCompensation},
    {sipName_pitchCompensationAvailability, meth_QMediaPlayer_pitchCompensationAvailability, METH_VARARGS, doc_QMediaPlayer_pitchCompensationAvailability},
    {sipName_play, meth_QMediaPlayer_play, METH_VARARGS, doc_QMediaPlayer_play},
    {sipName_playbackOptions, meth_QMediaPlayer_playbackOptions, METH_VARARGS, doc_QMediaPlayer_playbackOptions},
    {sipName_playbackRate, meth_QMediaPlayer_playbackRate, METH_VARARGS, doc_QMediaPlayer_playbackRate},
    {sipName_playbackState, meth_QMediaPlayer_playbackState, METH_VARARGS, doc_QMediaPlayer_playbackState},
    {sipName_position, meth_QMediaPlayer_position, METH_VARARGS, doc_QMediaPlayer_position},
    {sipName_resetPlaybackOptions, meth_QMediaPlayer_resetPlaybackOptions, METH_VARARGS, doc_QMediaPlayer_resetPlaybackOptions},
    {sipName_setActiveAudioTrack, meth_QMediaPlayer_setActiveAudioTrack, METH_VARARGS, doc_QMediaPlayer_setActiveAudioTrack},
    {sipName_setActiveSubtitleTrack, meth_QMediaPlayer_setActiveSubtitleTrack, METH_VARARGS, doc_QMediaPlayer_setActiveSubtitleTrack},
    {sipName_setActiveVideoTrack, meth_QMediaPlayer_setActiveVideoTrack, METH_VARARGS, doc_QMediaPlayer_setActiveVideoTrack},
    {sipName_setAudioBufferOutput, meth_QMediaPlayer_setAudioBufferOutput, METH_VARARGS, doc_QMediaPlayer_setAudioBufferOutput},
    {sipName_setAudioOutput, meth_QMediaPlayer_setAudioOutput, METH_VARARGS, doc_QMediaPlayer_setAudioOutput},
    {sipName_setLoops, meth_QMediaPlayer_setLoops, METH_VARARGS, doc_QMediaPlayer_setLoops},
    {sipName_setPitchCompensation, meth_QMediaPlayer_setPitchCompensation, METH_VARARGS, doc_QMediaPlayer_setPitchCompensation},
    {sipName_setPlaybackOptions, meth_QMediaPlayer_setPlaybackOptions, METH_VARARGS, doc_QMediaPlayer_setPlaybackOptions},
    {sipName_setPlaybackRate, meth_QMediaPlayer_setPlaybackRate, METH_VARARGS, doc_QMediaPlayer_setPlaybackRate},
    {sipName_setPosition, meth_QMediaPlayer_setPosition, METH_VARARGS, doc_QMediaPlayer_setPosition},
    {sipName_setSource, meth_QMediaPlayer_setSource, METH_VARARGS, doc_QMediaPlayer_setSource},
    {sipName_setSourceDevice, SIP_MLMETH_CAST(meth_QMediaPlayer_setSourceDevice), METH_VARARGS|METH_KEYWORDS, doc_QMediaPlayer_setSourceDevice},
    {sipName_setVideoOutput, meth_QMediaPlayer_setVideoOutput, METH_VARARGS, doc_QMediaPlayer_setVideoOutput},
    {sipName_setVideoSink, meth_QMediaPlayer_setVideoSink, METH_VARARGS, doc_QMediaPlayer_setVideoSink},
    {sipName_source, meth_QMediaPlayer_source, METH_VARARGS, doc_QMediaPlayer_source},
    {sipName_sourceDevice, meth_QMediaPlayer_sourceDevice, METH_VARARGS, doc_QMediaPlayer_sourceDevice},
    {sipName_stop, meth_QMediaPlayer_stop, METH_VARARGS, doc_QMediaPlayer_stop},
    {sipName_subtitleTracks, meth_QMediaPlayer_subtitleTracks, METH_VARARGS, doc_QMediaPlayer_subtitleTracks},
    {sipName_videoOutput, meth_QMediaPlayer_videoOutput, METH_VARARGS, doc_QMediaPlayer_videoOutput},
    {sipName_videoSink, meth_QMediaPlayer_videoSink, METH_VARARGS, doc_QMediaPlayer_videoSink},
    {sipName_videoTracks, meth_QMediaPlayer_videoTracks, METH_VARARGS, doc_QMediaPlayer_videoTracks}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QMediaPlayer[] = {
    {sipName_NoError, static_cast<int>(::QMediaPlayer::NoError)},
    {sipName_ResourceError, static_cast<int>(::QMediaPlayer::ResourceError)},
    {sipName_FormatError, static_cast<int>(::QMediaPlayer::FormatError)},
    {sipName_NetworkError, static_cast<int>(::QMediaPlayer::NetworkError)},
    {sipName_AccessDeniedError, static_cast<int>(::QMediaPlayer::AccessDeniedError)},
    {sipName_Infinite, static_cast<int>(::QMediaPlayer::Infinite)},
    {sipName_Once, static_cast<int>(::QMediaPlayer::Once)},
    {sipName_NoMedia, static_cast<int>(::QMediaPlayer::NoMedia)},
    {sipName_LoadingMedia, static_cast<int>(::QMediaPlayer::LoadingMedia)},
    {sipName_LoadedMedia, static_cast<int>(::QMediaPlayer::LoadedMedia)},
    {sipName_StalledMedia, static_cast<int>(::QMediaPlayer::StalledMedia)},
    {sipName_BufferingMedia, static_cast<int>(::QMediaPlayer::BufferingMedia)},
    {sipName_BufferedMedia, static_cast<int>(::QMediaPlayer::BufferedMedia)},
    {sipName_EndOfMedia, static_cast<int>(::QMediaPlayer::EndOfMedia)},
    {sipName_InvalidMedia, static_cast<int>(::QMediaPlayer::InvalidMedia)},
    {sipName_AlwaysOn, static_cast<int>(::QMediaPlayer::PitchCompensationAvailability::AlwaysOn)},
    {sipName_Available, static_cast<int>(::QMediaPlayer::PitchCompensationAvailability::Available)},
    {sipName_Unavailable, static_cast<int>(::QMediaPlayer::PitchCompensationAvailability::Unavailable)},
    {sipName_StoppedState, static_cast<int>(::QMediaPlayer::StoppedState)},
    {sipName_PlayingState, static_cast<int>(::QMediaPlayer::PlayingState)},
    {sipName_PausedState, static_cast<int>(::QMediaPlayer::PausedState)},
    {0, 0}
};

PyDoc_STRVAR(doc_QMediaPlayer, "\1QMediaPlayer(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QMediaPlayer[] = {
    {"playbackOptionsChanged()", "\1playbackOptionsChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"pitchCompensationChanged(bool)", "\1pitchCompensationChanged(self, a0: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"audioBufferOutputChanged()", "\1audioBufferOutputChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"playingChanged(bool)", "\1playingChanged(self, playing: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"loopsChanged()", "\1loopsChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorOccurred(QMediaPlayer::Error,QString)", "\1errorOccurred(self, error: QMediaPlayer.Error, errorString: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorChanged()", "\1errorChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"activeTracksChanged()", "\1activeTracksChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"tracksChanged()", "\1tracksChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"audioOutputChanged()", "\1audioOutputChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"videoOutputChanged()", "\1videoOutputChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"metaDataChanged()", "\1metaDataChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"playbackRateChanged(qreal)", "\1playbackRateChanged(self, rate: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"seekableChanged(bool)", "\1seekableChanged(self, seekable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"bufferProgressChanged(float)", "\1bufferProgressChanged(self, progress: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"hasVideoChanged(bool)", "\1hasVideoChanged(self, videoAvailable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"hasAudioChanged(bool)", "\1hasAudioChanged(self, available: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionChanged(qint64)", "\1positionChanged(self, position: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"durationChanged(qint64)", "\1durationChanged(self, duration: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"mediaStatusChanged(QMediaPlayer::MediaStatus)", "\1mediaStatusChanged(self, status: QMediaPlayer.MediaStatus)", SIP_NULLPTR, SIP_NULLPTR},
    {"playbackStateChanged(QMediaPlayer::PlaybackState)", "\1playbackStateChanged(self, newState: QMediaPlayer.PlaybackState)", SIP_NULLPTR, SIP_NULLPTR},
    {"sourceChanged(QUrl)", "\1sourceChanged(self, media: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QMediaPlayer = {
    &::QMediaPlayer::staticMetaObject,
    signals_QMediaPlayer,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QMediaPlayer = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMediaPlayer,
        SIP_NULLPTR,
        &plugin_QMediaPlayer,
    },
    {
        sipNameNr_QMediaPlayer,
        {0, 0, 1},
        49, methods_QMediaPlayer,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QMediaPlayer, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMediaPlayer,
    -1,
    -1,
    supers_QMediaPlayer,
    SIP_NULLPTR,
    init_type_QMediaPlayer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMediaPlayer,
    SIP_NULLPTR,
    array_QMediaPlayer,
    SIP_NULLPTR,
    release_QMediaPlayer,
    cast_QMediaPlayer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QMediaPlayer,
    sizeof (::QMediaPlayer),
};
